==> smart_select-2.0.0.tar.gz: example/README.md <==
# Demo App

[![Demo App](https://github.com/davigmacode/flutter_smart_select/raw/master/example/art/qr/apk.png "Demo App")](https://github.com/davigmacode/flutter_smart_select/blob/master/example/art/demo/SmartSelect.apk?raw=true)

# Source Code

## Single Choice

* [Open in Full Page](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_page.dart)
* [Open in Bottom Sheet](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_sheet.dart)
* [Open in Popup Dialog](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_popup.dart)
* [Use Chips](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_chips.dart)

## Multiple Choice

* [Open in Full Page](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_page.dart)
* [Open in Bottom Sheet](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_sheet.dart)
* [Open in Popup Dialog](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_popup.dart)
* [Use Chips](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_chips.dart)
* [Use Switches](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_switches.dart)

## Customize Tile

* [One Line](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_one_line.dart)
* [Two Line](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_two_line.dart)
* [Leading Widget](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_leading.dart)
* [Custom Trailing Widget](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_trailing.dart)
* [Loading Stats](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_loading.dart)
* [Custom Tile Builder]((https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_builder.dart))


## Customize Option

* [List of Map](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_list_of_map.dart)
* [List of String](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_list_of_string.dart)
* [List of List Of String](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_list_of_list.dart)
* [Async Option & Custom Properties](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_async.dart)

## Customize Modal

* [Use Filter](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_filter.dart)
* [Need to Confirm](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_confirm.dart)
* [Modal Shape](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_shape.dart)
* [Modal Header](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_header.dart)
* [Without Header](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_headerless.dart)

## Customize Choices

* [Grouped Items](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_choices/choices_grouped.dart)
* [Use Divider Between Item](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_choices/choices_divider.dart)
* [Customize Theme](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_choices/choices_theme.dart)

==> smart_select-2.0.1.tar.gz: example/README.md <==
# Demo App

## Preview

[![Watch the demo](https://img.youtube.com/vi/bcHELDM8hWg/maxresdefault.jpg)](https://youtu.be/bcHELDM8hWg)

## Download

[![Demo App](https://github.com/davigmacode/flutter_smart_select/raw/master/example/art/qr/apk.png "Demo App")](https://github.com/davigmacode/flutter_smart_select/blob/master/example/art/demo/SmartSelect.apk?raw=true)

# Source Code

## Single Choice

* [Open in Full Page](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_page.dart)
* [Open in Bottom Sheet](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_sheet.dart)
* [Open in Popup Dialog](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_popup.dart)
* [Use Chips](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_single/single_chips.dart)

## Multiple Choice

* [Open in Full Page](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_page.dart)
* [Open in Bottom Sheet](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_sheet.dart)
* [Open in Popup Dialog](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_popup.dart)
* [Use Chips](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_chips.dart)
* [Use Switches](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_multi/multi_switches.dart)

## Customize Tile

* [One Line](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_one_line.dart)
* [Two Line](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_two_line.dart)
* [Leading Widget](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_leading.dart)
* [Custom Trailing Widget](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_trailing.dart)
* [Loading Stats](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_loading.dart)
* [Custom Tile Builder](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_tile/tile_builder.dart)


## Customize Option

* [List of Map](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_list_of_map.dart)
* [List of String](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_list_of_string.dart)
* [List of List Of String](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_list_of_list.dart)
* [Async Option & Custom Properties](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_option/option_async.dart)

## Customize Modal

* [Use Filter](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_filter.dart)
* [Need to Confirm](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_confirm.dart)
* [Modal Shape](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_shape.dart)
* [Modal Header](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_header.dart)
* [Without Header](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_modal/modal_headerless.dart)

## Customize Choices

* [Grouped Items](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_choices/choices_grouped.dart)
* [Use Divider Between Item](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_choices/choices_divider.dart)
* [Customize Theme](https://github.com/davigmacode/flutter_smart_select/blob/master/example/lib/features_choices/choices_theme.dart)
